@@ -16,8 +16,8 @@
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *    along with this program; if not, write to the Free Software Foundation, Inc.,
+ *    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *    Author: Neil Brown
  *    Email: <neilb@suse.de>
@@ -29,11 +29,9 @@
 
 #include "wiggle.h"
 
-char Version[] = "wiggle - v0.8 - 24 March 2010\n";
-
-char short_options1[]="xdmwlrhi123pVRvqB"; /* not mode B */
-char short_options2[]="xdmwlrhi123p:VRvqB"; /* mode B */
+char Version[] = "wiggle 0.9.1 2013-02-05 GPL-2+ http://neil.brown.name/wiggle/\n";
 
+char short_options[] = "xdmwlrhiW123p::VRvqB";
 
 struct option long_options[] = {
 	{"browse",	0, 0, 'B'},
@@ -51,6 +49,7 @@ struct option long_options[] = {
 	{"quiet",	0, 0, 'q'},
 	{"strip",	1, 0, 'p'},
 	{"no-ignore",	0, 0, 'i'},
+	{"show-wiggle",	0, 0, 'W'},
 	{0, 0, 0, 0}
 };
 
@@ -60,7 +59,7 @@ char Usage[] =
 char Help[] =  "\n"
 "Wiggle - apply patches that 'patch' rejects.\n"
 "\n"
-"Wiggle provides three distinct but related functions:\n"
+"Wiggle provides four distinct but related functions:\n"
 "merge, diff, extract, and browse.\n"
 "To get more detailed help on a function, select the function\n"
 "before requesting help.  e.g.\n"
@@ -78,6 +77,8 @@ char Help[] =  "\n"
 "   --patch     -p    : treat last file as a patch file.\n"
 "   -1  -2  -3        : select which component of patch or merge to use.\n"
 "   --reverse   -R    : swap 'before' and 'after' for diff function.\n"
+"   --no-ignore -i    : Don't ignore already-applied changes.\n"
+"   --show-wiggle -W  : Report wiggles like conflicts with an extra stanza.\n"
 "\n"
 "   --help      -h    : get help.\n"
 "   --version   -V    : get version of wiggle.\n"
@@ -95,7 +96,7 @@ char Help[] =  "\n"
 char HelpExtract[] = "\n"
 "wiggle --extract -[123] [--patch]  merge-or-patch\n"
 "\n"
-"The extract function allows one banch of a patch or merge file\n"
+"The extract function allows one branch of a patch or merge file\n"
 "to be extracted.  A 'patch' is the output of 'diff -c' or 'diff -u'.\n"
 "Either the before (-1) or after (-2) branch can be extracted.\n"
 "\n"
@@ -121,7 +122,7 @@ char HelpDiff[] = "\n"
 "second is treated as a patch and the first or (with -2) second branch\n"
 "is extracted and compared against the first file.\n"
 "\n"
-"--reverse (-R) with cause diff two swap the two files before comparing\n"
+"--reverse (-R) with cause diff to swap the two files before comparing\n"
 "them.\n"
 "\n";
 
@@ -135,11 +136,13 @@ char HelpMerge[] = "\n"
 "output unresolvable conflicts in the resulting merge by showing\n"
 "whole-line differences.\n"
 "With the --lines option, the files are compared line-wise much\n"
-"like 'merge'.  With the --words option, files are compared\n"
+"like 'merge'.  With the (default) --words option, files are compared\n"
 "word-wise and unresolvable conflicts are reported word-wise.\n"
 "\n"
 "If --merge is given one file, it is treated as a merge (merge -A\n"
 "output) and the three needed streams are extracted from it.\n"
+"If --merge is given one file and -p, it is a patch which identifies\n"
+"the files that should be patched.\n"
 "If --merge is given two files, the second is treated as a patch\n"
 "file and the first is the original file.\n"
 "If --merge is given three files, they are each treated as whole files\n"
@@ -148,10 +151,19 @@ char HelpMerge[] = "\n"
 "\n";
 
 char HelpBrowse[] = "\n"
-"wiggle --browse [-R] [--strip=n] multi-file-patch\n"
+"wiggle --browse [-R] [--strip=n] [-p] [files]\n"
 "\n"
 "The 'browse' function provides an interactive mode for browsing a\n"
-"set of patches.  It allows the application of a patch to each file \n"
-"to be inspected and allows limited editting to correct mis-application\n"
-"of patches where wiggling was required, and where conflicts occurred.\n"
+"patch or set of patches.  It allows the application of a patch to each\n"
+"file to be inspected and will eventually allow limited editing to correct\n"
+"mis-application of patches where wiggling was required, and where conflicts\n"
+"occurred.\n"
+"If no files are given, a patch file is read from stdin\n"
+"If one file is given with -p, it is treated as a patch file\n"
+"If one file is given with a name ending .rej, it is treated as a reject for\n"
+"     a file with matching basename\n"
+"Otherwise a single file is assumed to be a merge output with conflicts.\n"
+"If two files are given, the second is a patch to apply to the first.\n"
+"If three files are given then the difference between 2nd and 3rd is applied\n"
+"     to the first\n"
 "\n";
